@@ -3,11 +3,12 @@ use 5.014000;
 use strict;
 use warnings;
 
-our $VERSION = '1.002001';
+our $VERSION = '1.003';
 
 use HTML::Template::Compiled qw//;
 use Memoize qw/memoize/;
 
+use Carp qw/carp/;
 use DB_File qw//;
 use Encode qw/encode/;
 use File::Basename qw/fileparse/;
@@ -121,7 +122,7 @@ sub opusinfo {
 		tracknumber => $tags->query('TRACKNUMBER'),
 		tracktotal => $tags->query('TRACKTOTAL'),
 		genre => $tags->query('GENRE'),
-		file => scalar fileparse $file
+		file => scalar fileparse $file,
 	);
 
 	freeze \%data;
@@ -132,7 +133,7 @@ my @optional_modules = (
 	[ 'MP3::Info', \&mp3info, '.mp3' ],
 	[ 'Ogg::Vorbis::Header::PurePerl', \&vorbisinfo, '.ogg', '.oga' ],
 	[ 'MP4::Info', \&mp4info, '.mp4', '.aac', '.m4a' ],
-	[ 'Audio::Opusfile', \&opusinfo, '.opus' ]
+	[ 'Audio::Opusfile', \&opusinfo, '.opus' ],
 );
 
 my %info;
@@ -145,7 +146,7 @@ for (@optional_modules) {
 }
 
 unless (%info) {
-	warn 'No tags-reading module detected. Install one of the following modules: ' . join ', ', map { $_->[0] } @optional_modules;
+	carp 'No tags-reading module detected. Install one of the following modules: ' . join ', ', map { $_->[0] } @optional_modules;
 }
 
 sub normalizer{
@@ -267,7 +268,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2016 by Marius Gavrilescu
+Copyright (C) 2013-2017 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
